@@ -5,7 +5,7 @@
 # This module is free software; you can redistribute it and/or modify it under
 # the same terms as Perl itself, i.e. under the terms of either the GNU General
 # Public License or the Artistic License, as specified in the F<LICENCE> file.
-package	Cmd;
+package	Grips::Cmd;
 
 use strict;
 use warnings;
@@ -13,7 +13,7 @@ use Carp;
 use IO::Socket;
 use Data::Dumper;
 #use Parse::RecDescent;
-use Grips::Gripsrc;;
+use Grips::Gripsrc;
     
 use vars qw($AUTOLOAD @EXPORT_OK $VERSION);
 
@@ -21,7 +21,7 @@ require Exporter;
 
 our @ISA = qw(Exporter);
 
-$VERSION = "1.09";
+$VERSION = "1.10";
 
 @EXPORT_OK = qw(checkGripsResponse);
 
@@ -948,8 +948,8 @@ Grips::Cmd - Perl-Schnittstelle zur grips-open Skriptsprache
 
 =head1 SYNOPSIS
 
-    use grips::Cmd;
-    $grips = new Cmd(host => 'gripsdb.dimdi.de', port => 5101);
+    use Grips::Cmd;
+    $grips = new Grips::Cmd(host => 'gripsdb.dimdi.de', port => 5101);
     $grips->login(user => '1234abcd', pwd => "");
     $grips->setAttribute(grips_object_name => $grips->getSessionID, timeout => 600);
     $grips->defineBase(grips_object_name => $grips->getSessionID, id => "bas1", dbs => ["ml66"]);
@@ -1435,7 +1435,9 @@ muss.
 
     - new response syntax implementiert
 
-=head1 AUTHOR
+    1.10
+
+    - Fix package declaration=head1 AUTHOR
 
 Tarek Ahmed, E<lt>ahmed@dimdi.deE<gt>
 
